# Access Tokens Required for SCIM
### On this page
  * [Get a Short-Lived Access Token](https://help.sap.com/docs/leanix/ea/access-tokens-required-for-scim#get-a-short-lived-access-token)
  * [Get a Long-Lived Access Token](https://help.sap.com/docs/leanix/ea/access-tokens-required-for-scim#get-a-long-lived-access-token)
  * [Get All Long-Lived Access Tokens](https://help.sap.com/docs/leanix/ea/access-tokens-required-for-scim#get-all-long-lived-access-tokens)
  * [Deactivate a Long-Lived Access Token](https://help.sap.com/docs/leanix/ea/access-tokens-required-for-scim#deactivate-a-long-lived-access-token)


Learn how to obtain and manage long-lived access tokens required for SCIM.
To configure SCIM, you need a long-lived access token. In this guide, you’ll learn how to obtain, retrieve, and deactivate access tokens through the MTM REST API. To view reference documentation for the MTM API, navigate to the [OpenAPI Explorer![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%3Furls.primaryName%3DMTM "https://app.leanix.net/openapi-explorer/?urls.primaryName=MTM").
